==> xoonips-3.46a.zip: xoonips-3.46a/itemtypes/xnpbinder/language/english/main.php <==
<?php
// $Revision: 1.1.1.6 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
define('_MD_XNPBINDER_ITEMS_TO_REGISTER_TITLE', 'Items to be registered');
define('_MD_XNPBINDER_DELETE_CHECKED_ITEM_BUTTON_LABEL', 'Delete checked items');
define('_MD_XNPBINDER_REGISTERED_ITEMS_TITLE', 'Registerd items');
define('_MD_XNPBINDER_ITEM_REQUIRED', 'At least one item is required');
define('_MD_XNPBINDER_ITEM_LABEL', "Items");
define("_MD_XNPBINDER_REMOVE_NONPUBLIC_ITEM", "This binder cannot be public binder because it contains %d non-public items. Do you want to remove them from binder?");
define("_MD_XNPBINDER_REMOVE_PRIVATE_ITEM", "This binder cannot be group binder because it contains %d private items. Do you want to remove them from binder?");
define('_MD_XNPBINDER_EXPLANATION', 'Binder');
define('_MD_XNPBINDER_GROUP_BINDER_HAS_PRIVATE_ITEM', 'This group binder contains some private items.');
define('_MD_XNPBINDER_PUBLIC_BINDER_HAS_NOT_PUBLIC_ITEM', 'This public binder contains some group or private items.');
define('_MD_XNPBINDER_USER_CONTENT_EMPTY_NOTIFYSBJ', 'Public or group-shared binder became empty');
define( '_MD_XNPBINDER_XMLRPC_DISPLAY_NAME_BINDER_ID', 'Item ID' );
define( '_MD_XNPBINDER_XMLRPC_DISPLAY_NAME_ITEM_ID'  , 'Binder Items' );

?>

==> xoonips-3.49.zip: xoonips-3.49/itemtypes/xnpbinder/language/english/main.php <==
<?php

// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
define('_MD_XNPBINDER_ITEMS_TO_REGISTER_TITLE', 'Items to be registered');
define('_MD_XNPBINDER_DELETE_CHECKED_ITEM_BUTTON_LABEL', 'Delete checked items');
define('_MD_XNPBINDER_REGISTERED_ITEMS_TITLE', 'Registerd items');
define('_MD_XNPBINDER_ITEM_REQUIRED', 'At least one item is required');
define('_MD_XNPBINDER_ITEM_LABEL', 'Items');
define('_MD_XNPBINDER_REMOVE_NONPUBLIC_ITEM', 'This binder cannot be public binder because it contains %d non-public items. Do you want to remove them from binder?');
define('_MD_XNPBINDER_REMOVE_PRIVATE_ITEM', 'This binder cannot be group binder because it contains %d private items. Do you want to remove them from binder?');
define('_MD_XNPBINDER_EXPLANATION', 'Binder');
define('_MD_XNPBINDER_GROUP_BINDER_HAS_PRIVATE_ITEM', 'This group binder contains some private items.');
define('_MD_XNPBINDER_PUBLIC_BINDER_HAS_NOT_PUBLIC_ITEM', 'This public binder contains some group or private items.');
define('_MD_XNPBINDER_USER_CONTENT_EMPTY_NOTIFYSBJ', 'Public or group-shared binder became empty');
define('_MD_XNPBINDER_XMLRPC_DISPLAY_NAME_BINDER_ID', 'Item ID');
define('_MD_XNPBINDER_XMLRPC_DISPLAY_NAME_ITEM_ID', 'Binder Items');
